=== modified file 'drizzled/Makefile.am'
--- drizzled/Makefile.am	2009-11-13 18:55:43 +0000
+++ drizzled/Makefile.am	2009-11-21 02:00:39 +0000
@@ -369,6 +369,7 @@
 		symbol_hash.h \
 		table.h \
 		table_ident.h \
+		table_identifier.h \
 		table_list.h \
 		table_map_iterator.h \
 		table_proto.h \

=== modified file 'drizzled/cursor.h'
--- drizzled/cursor.h	2009-11-19 20:11:37 +0000
+++ drizzled/cursor.h	2009-11-21 02:00:39 +0000
@@ -22,6 +22,7 @@
 
 #include <drizzled/xid.h>
 #include <drizzled/discrete_interval.h>
+#include <drizzled/table_identifier.h>
 
 /* Definitions for parameters to do with Cursor-routines */
 
@@ -845,7 +846,8 @@
                          int *timestamps, int *timestamps_with_niladic,
                          int64_t table_flags);
 
-bool mysql_create_table(Session *session,const char *db, const char *table_name,
+bool mysql_create_table(Session *session,
+                        drizzled::TableIdentifier &identifier,
                         HA_CREATE_INFO *create_info,
                         drizzled::message::Table *table_proto,
                         AlterInfo *alter_info,

=== modified file 'drizzled/server_includes.h'
--- drizzled/server_includes.h	2009-11-14 23:51:37 +0000
+++ drizzled/server_includes.h	2009-11-21 02:00:39 +0000
@@ -214,6 +214,7 @@
 bool check_table_name(const char *name, uint32_t length);
 
 /* Conversion functions */
+size_t build_tmptable_filename(char *buff, size_t bufflen);
 size_t build_table_filename(char *buff, size_t bufflen, const char *db, 
                             const char *table_name, bool is_tmp);
 

=== modified file 'drizzled/sql_insert.cc'
--- drizzled/sql_insert.cc	2009-11-20 01:08:36 +0000
+++ drizzled/sql_insert.cc	2009-11-21 02:00:39 +0000
@@ -1524,11 +1524,13 @@
     should not cause deadlocks or races.
   */
   {
-    if (!mysql_create_table_no_lock(session, create_table->db,
+    if (!mysql_create_table_no_lock(session,
+                                    create_table->db,
                                     create_table->table_name,
                                     create_info,
 				    table_proto,
-				    alter_info, false,
+				    alter_info,
+                                    false,
                                     select_field_count,
                                     is_if_not_exists))
     {

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2009-10-12 05:13:54 +0000
+++ drizzled/sql_parse.cc	2009-11-21 02:00:39 +0000
@@ -1659,20 +1659,15 @@
     true   Error
 */
 
-bool create_table_precheck(Session *, TableList *,
-                           TableList *create_table)
+bool create_table_precheck(TableIdentifier &identifier)
 {
-  bool error= true;                                 // Error message is given
-
-  if (create_table && (strcmp(create_table->db, "information_schema") == 0))
+  if (strcmp(identifier.getDBName(), "information_schema") == 0)
   {
     my_error(ER_DBACCESS_DENIED_ERROR, MYF(0), "", "", INFORMATION_SCHEMA_NAME.c_str());
-    return(true);
+    return true;
   }
 
-  error= false;
-
-  return(error);
+  return false;
 }
 
 

=== modified file 'drizzled/sql_parse.h'
--- drizzled/sql_parse.h	2009-10-13 06:22:10 +0000
+++ drizzled/sql_parse.h	2009-11-21 02:00:39 +0000
@@ -24,6 +24,7 @@
 #include "drizzled/common.h"
 #include "drizzled/lex_string.h"
 #include "drizzled/comp_creator.h"
+#include <drizzled/table_identifier.h>
 
 #include "mystrings/m_ctype.h"
 
@@ -40,8 +41,7 @@
 bool update_precheck(Session *session, TableList *tables);
 bool delete_precheck(Session *session, TableList *tables);
 bool insert_precheck(Session *session, TableList *tables);
-bool create_table_precheck(Session *session, TableList *tables,
-                           TableList *create_table);
+bool create_table_precheck(drizzled::TableIdentifier &identifier);
 
 Item *negate_expression(Session *session, Item *expr);
 

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2009-11-19 20:28:06 +0000
+++ drizzled/sql_table.cc	2009-11-21 02:00:39 +0000
@@ -34,6 +34,7 @@
 #include <drizzled/replication_services.h>
 #include <drizzled/table_proto.h>
 #include <drizzled/plugin/client.h>
+#include <drizzled/table_identifier.h>
 
 #include "drizzled/statement/alter_table.h" /* for drizzled::create_like_schema_frm, which will die soon */
 
@@ -286,13 +287,14 @@
     path length on success, 0 on failure
 */
 
-static uint32_t build_tmptable_filename(Session* session,
-                                        char *buff, size_t bufflen)
+size_t build_tmptable_filename(char *buff, size_t bufflen)
 {
-  uint32_t length;
+  size_t length;
   ostringstream path_str, post_tmpdir_str;
   string tmp;
 
+  Session *session= current_session;
+
   path_str << drizzle_tmpdir;
   post_tmpdir_str << "/" << TMP_FILE_PREFIX << current_pid;
   post_tmpdir_str << session->thread_id << session->tmp_table++;
@@ -1653,7 +1655,7 @@
       /* Check if table exists */
   if (lex_identified_temp_table)
   {
-    path_length= build_tmptable_filename(session, path, sizeof(path));
+    path_length= build_tmptable_filename(path, sizeof(path));
   }
   else
   {
@@ -1804,7 +1806,8 @@
   Database locking aware wrapper for mysql_create_table_no_lock(),
 */
 
-bool mysql_create_table(Session *session, const char *db, const char *table_name,
+bool mysql_create_table(Session *session,
+                        TableIdentifier &identifier,
                         HA_CREATE_INFO *create_info,
 			message::Table *table_proto,
                         AlterInfo *alter_info,
@@ -1819,7 +1822,9 @@
 
   if (! lex_identified_temp_table)
   {
-    if (session->lock_table_name_if_not_cached(db, table_name, &name_lock))
+    if (session->lock_table_name_if_not_cached(identifier.getDBName(),
+                                               identifier.getTableName(),
+                                               &name_lock))
     {
       result= true;
       goto unlock;
@@ -1830,20 +1835,23 @@
       {
         push_warning_printf(session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
                             ER_TABLE_EXISTS_ERROR, ER(ER_TABLE_EXISTS_ERROR),
-                            table_name);
+                            identifier.getTableName());
         create_info->table_existed= 1;
         result= false;
       }
       else
       {
-        my_error(ER_TABLE_EXISTS_ERROR,MYF(0),table_name);
+        my_error(ER_TABLE_EXISTS_ERROR, MYF(0), identifier.getTableName());
         result= true;
       }
       goto unlock;
     }
   }
 
-  result= mysql_create_table_no_lock(session, db, table_name, create_info,
+  result= mysql_create_table_no_lock(session,
+                                     identifier.getDBName(),
+                                     identifier.getTableName(),
+                                     create_info,
 				     table_proto,
                                      alter_info,
                                      internal_tmp_table,
@@ -2432,7 +2440,7 @@
   {
     if (session->find_temporary_table(db, table_name))
       goto table_exists;
-    dst_path_length= build_tmptable_filename(session, dst_path, sizeof(dst_path));
+    dst_path_length= build_tmptable_filename(dst_path, sizeof(dst_path));
   }
   else
   {

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2009-11-19 20:11:37 +0000
+++ drizzled/statement/alter_table.cc	2009-11-21 02:00:39 +0000
@@ -1424,8 +1424,15 @@
 {
   int error;
   plugin::StorageEngine *old_db_type, *new_db_type;
+  TableIdentifier identifier(new_db,
+                             tmp_name,
+                             create_proto->type() == message::Table::TEMPORARY ? NO_TMP_TABLE :
+                             create_info->db_type->check_flag(HTON_BIT_DOES_TRANSACTIONS) ? TRANSACTIONAL_TMP_TABLE : 
+                             NON_TRANSACTIONAL_TMP_TABLE );
+
   old_db_type= table->s->db_type();
   new_db_type= create_info->db_type;
+
   /*
     Create a table with a temporary name.
     We don't log the statement, it will be logged later.
@@ -1436,7 +1443,8 @@
   protoengine= create_proto->mutable_engine();
   protoengine->set_name(new_db_type->getName());
 
-  error= mysql_create_table(session, new_db, tmp_name,
+  error= mysql_create_table(session,
+                            identifier,
                             create_info, create_proto, alter_info, true, 0, false);
 
   return error;

=== modified file 'drizzled/statement/create_table.cc'
--- drizzled/statement/create_table.cc	2009-11-19 20:11:37 +0000
+++ drizzled/statement/create_table.cc	2009-11-21 02:00:39 +0000
@@ -23,6 +23,7 @@
 #include <drizzled/lock.h>
 #include <drizzled/session.h>
 #include <drizzled/statement/create_table.h>
+#include <drizzled/table_identifier.h>
 
 namespace drizzled
 {
@@ -42,7 +43,6 @@
 
   if (is_engine_set)
   {
-
     create_info.db_type= 
       plugin::StorageEngine::findByName(*session, create_table_proto.engine().name());
 
@@ -84,7 +84,19 @@
   TableList *create_table= session->lex->unlink_first_table(&link_to_local);
   TableList *select_tables= session->lex->query_tables;
 
-  if (create_table_precheck(session, select_tables, create_table))
+
+  /* 
+    Now that we have the engine, we can figure out the table identifier. We need the engine in order
+    to determine if the table is transactional or not if it is temp.
+  */
+  TableIdentifier new_table_identifier(create_table->db,
+                                       create_table->table_name, 
+                                       create_table_proto.type() == message::Table::TEMPORARY ? NO_TMP_TABLE :
+                                       create_info.db_type->check_flag(HTON_BIT_DOES_TRANSACTIONS) ? TRANSACTIONAL_TMP_TABLE : 
+                                       NON_TRANSACTIONAL_TMP_TABLE );
+
+
+  if (create_table_precheck(new_table_identifier))
   {
     /* put tables back for PS rexecuting */
     session->lex->link_first_table_back(create_table, link_to_local);
@@ -202,8 +214,7 @@
       }
 
       res= mysql_create_table(session, 
-                              create_table->db,
-                              create_table->table_name, 
+                              new_table_identifier,
                               &create_info,
                               &create_table_proto,
                               &alter_info, 

=== added file 'drizzled/table_identifier.h'
--- drizzled/table_identifier.h	1970-01-01 00:00:00 +0000
+++ drizzled/table_identifier.h	2009-11-21 02:00:39 +0000
@@ -0,0 +1,111 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2009 Sun Microsystems
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+/* 
+  This is a "work in progress". The concept needs to be replicated throughout
+  the code, but we will start with baby steps for the moment. To not incur
+  cost until we are complete, for the moment it will do no allocation.
+
+  This is mainly here so that it can be used in the SE interface for
+  the time being.
+
+  This will replace Table_ident.
+  */
+
+#ifndef DRIZZLED_TABLE_IDENTIFIER_H
+#define DRIZZLED_TABLE_IDENTIFIER_H
+
+#include <string.h>
+
+size_t build_tmptable_filename(char *buff, size_t bufflen);
+size_t build_table_filename(char *buff, size_t bufflen, const char *db, const char *table_name, bool is_tmp);
+
+
+namespace drizzled {
+
+class TableIdentifier 
+{
+private:
+  bool path_inited;
+  tmp_table_type type;
+  char path[FN_REFLEN];
+  const char *db;
+  const char *table_name;
+
+public:
+  TableIdentifier( const char *db_arg,
+                   const char *table_name_arg,
+                   tmp_table_type tmp_arg) :
+    path_inited(false),
+    type(tmp_arg),
+    db(db_arg),
+    table_name(table_name_arg)
+  { 
+  }
+
+  bool isTmp()
+  {
+    return type == NO_TMP_TABLE ? false  : true;
+  }
+
+  const char *getPath()
+  {
+    if (! path_inited)
+    {
+      size_t path_length;
+
+      switch (type) {
+      case NO_TMP_TABLE:
+        path_length= build_table_filename(path, sizeof(path),
+                                          db, table_name,
+                                          false);
+        break;
+      case INTERNAL_TMP_TABLE:
+        path_length= build_table_filename(path, sizeof(path),
+                                          db, table_name,
+                                          true);
+        break;
+      case NON_TRANSACTIONAL_TMP_TABLE:
+      case TRANSACTIONAL_TMP_TABLE:
+        build_tmptable_filename(path, sizeof(path));
+        break;
+      case SYSTEM_TMP_TABLE:
+        assert(0);
+      }
+      assert(path_length); // TODO throw exception, this is a possibility
+    }
+
+    return path;
+  }
+
+  const char *getDBName()
+  {
+    return db;
+  }
+
+  const char *getTableName()
+  {
+    return table_name;
+  }
+};
+
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_TABLE_IDENTIFIER_H */

